@@ -3,26 +3,32 @@ import optparse
 from autojenkins import Jenkins
 
 
-def create_opts_parser():
+def create_opts_parser(command):
+    """
+    Create parser for command-line options
+    """
     usage = "Usage: %prog host jobname [options]"
-    desc = 'Run autojenkins to create a job.'
+    desc = 'Run autojenkins to {0} a job.'.format(command)
     parser = optparse.OptionParser(description=desc, usage=usage)
     #parser.add_option('jobname',
     #                    help='the name of a job in jenkins')
-    parser.add_option('-D', metavar='PROP=VALUE',
-                      action="append",
-                      help='substitution variables to be used in the template')
-    parser.add_option('-t', '--template', default='template',
-                      help='the template job to copy from')
-    parser.add_option('-b', '--build',
-                      action="store_true", dest="build", default=False,
-                      help='start a build right after creation')
     return parser
 
 
-def run_jenkins(host, jobname, options):
-    spliteq = lambda x : x.split('=')
-    data = dict(map(spliteq, options.D))
+def get_variables(options):
+    """
+    Read all variables and values from ``-Dvariable=value`` options
+    """
+    split_eq = lambda x: x.split('=')
+    data = dict(map(split_eq, options.D))
+    return data
+
+
+def create_job(host, jobname, options):
+    """
+    Create a new job
+    """
+    data = get_variables(options)
 
     print ("""
     Creating job '{0}' from template '{1}' with:
@@ -31,8 +37,18 @@ def run_jenkins(host, jobname, options):
 
     jenkins = Jenkins(host)
     response = jenkins.create_copy(jobname, options.template, **data)
-    print('Status: {0}'.format(response.status_code))
     if response.status_code == 200 and options.build:
         print('Triggering build.')
         j.build(jobname)
+    return response.status_code
 
+
+def delete_job(host, jobname):
+    """
+    Delete an existing job
+    """
+    print ("Deleting job '{0}'".format(jobname))
+
+    jenkins = Jenkins(host)
+    response = jenkins.delete(jobname)
+    print('Status: {0}'.format(response.status_code))
